@@ -232,7 +232,7 @@ extensions += ['sphinx_favicon']
 html_static_path = ['images']  # should contain the folder with icons
 
 # Add support for nice Not Found 404 pages
-# extensions += ['notfound.extension']  # readthedocs/sphinx-notfound-page#219
+extensions += ['notfound.extension']
 
 # List of dicts with <link> HTML attributes
 # static-file points to files in the html_static_path (href is computed)
