@@ -35,15 +35,10 @@ def test_glob_relative(tmp_path, monkeypatch):
 
 
 def test_read_files(tmp_path, monkeypatch):
-
     dir_ = tmp_path / "dir_"
     (tmp_path / "_dir").mkdir(exist_ok=True)
     (tmp_path / "a.txt").touch()
-    files = {
-        "a.txt": "a",
-        "dir1/b.txt": "b",
-        "dir1/dir2/c.txt": "c"
-    }
+    files = {"a.txt": "a", "dir1/b.txt": "b", "dir1/dir2/c.txt": "c"}
     write_files(files, dir_)
 
     secrets = Path(str(dir_) + "secrets")
@@ -77,7 +72,7 @@ class TestReadAttr:
             # If a cookie is present, honor it:
             b"# -*- coding: utf-8 -*-\n__version__ = '\xc3\xa9'\nraise SystemExit(1)\n",
             b"# -*- coding: latin1 -*-\n__version__ = '\xe9'\nraise SystemExit(1)\n",
-        ]
+        ],
     )
     def test_read_attr_encoding_cookie(self, example, tmp_path):
         (tmp_path / "mod.py").write_bytes(example)
@@ -88,8 +83,7 @@ class TestReadAttr:
             "pkg/__init__.py": "",
             "pkg/sub/__init__.py": "VERSION = '0.1.1'",
             "pkg/sub/mod.py": (
-                "VALUES = {'a': 0, 'b': {42}, 'c': (0, 1, 1)}\n"
-                "raise SystemExit(1)"
+                "VALUES = {'a': 0, 'b': {42}, 'c': (0, 1, 1)}\n" "raise SystemExit(1)"
             ),
         }
         write_files(files, tmp_path)
@@ -113,7 +107,7 @@ class TestReadAttr:
         [
             "VERSION: str\nVERSION = '0.1.1'\nraise SystemExit(1)\n",
             "VERSION: str = '0.1.1'\nraise SystemExit(1)\n",
-        ]
+        ],
     )
     def test_read_annotated_attr(self, tmp_path, example):
         files = {
@@ -151,7 +145,7 @@ class TestReadAttr:
         ({"pkg": "lib"}, "lib/main.py", "pkg.main", 13),
         ({}, "single_module.py", "single_module", 70),
         ({}, "flat_layout/pkg.py", "flat_layout.pkg", 836),
-    ]
+    ],
 )
 def test_resolve_class(tmp_path, package_dir, file, module, return_value):
     files = {file: f"class Custom:\n    def testing(self): return {return_value}"}
@@ -167,7 +161,7 @@ def test_resolve_class(tmp_path, package_dir, file, module, return_value):
         ({"where": [".", "dir1"], "namespaces": False}, {"pkg", "other", "dir2"}),
         ({"namespaces": True}, {"pkg", "other", "dir1", "dir1.dir2"}),
         ({}, {"pkg", "other", "dir1", "dir1.dir2"}),  # default value for `namespaces`
-    ]
+    ],
 )
 def test_find_packages(tmp_path, args, pkgs):
     files = {
